@@ -19,7 +19,7 @@
 
 #define QT_FEATURE_simulator_and_device -1
 
-#define QT_FEATURE_rpath 1
+#define QT_FEATURE_rpath -1
 
 #define QT_FEATURE_force_asserts -1
 
@@ -33,7 +33,7 @@
 
 #define QT_FEATURE_cxx2c -1
 
-#define QT_FEATURE_reduce_relocations -1
+#define QT_FEATURE_reduce_relocations 1
 
 #define QT_FEATURE_signaling_nan 1
 
@@ -62,22 +62,41 @@
 #define QT_FEATURE_test_gui 1
 
 
-#define QT_VERSION_STR "6.10.2"
+#define QT_VERSION_STR "6.10.3"
 
 #define QT_VERSION_MAJOR 6
 
 #define QT_VERSION_MINOR 10
 
-#define QT_VERSION_PATCH 2
+#define QT_VERSION_PATCH 3
 
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
-#define QT_COMPILER_SUPPORTS_NEON 1
-#define QT_COMPILER_SUPPORTS_CRC32 1
-#define QT_COMPILER_SUPPORTS_CRYPTO 1
+#define QT_REDUCE_RELOCATIONS
+#define QT_COMPILER_SUPPORTS_SSE2 1
+#define QT_COMPILER_SUPPORTS_SSE3 1
+#define QT_COMPILER_SUPPORTS_SSSE3 1
+#define QT_COMPILER_SUPPORTS_SSE4_1 1
+#define QT_COMPILER_SUPPORTS_SSE4_2 1
+#define QT_COMPILER_SUPPORTS_AVX 1
+#define QT_COMPILER_SUPPORTS_F16C 1
+#define QT_COMPILER_SUPPORTS_AVX2 1
+#define QT_COMPILER_SUPPORTS_AVX512F 1
+#define QT_COMPILER_SUPPORTS_AVX512ER 1
+#define QT_COMPILER_SUPPORTS_AVX512CD 1
+#define QT_COMPILER_SUPPORTS_AVX512PF 1
+#define QT_COMPILER_SUPPORTS_AVX512DQ 1
+#define QT_COMPILER_SUPPORTS_AVX512BW 1
+#define QT_COMPILER_SUPPORTS_AVX512VL 1
+#define QT_COMPILER_SUPPORTS_AVX512IFMA 1
+#define QT_COMPILER_SUPPORTS_AVX512VBMI 1
+#define QT_COMPILER_SUPPORTS_AVX512VBMI2 1
 #define QT_COMPILER_SUPPORTS_AES 1
-#define QT_COMPILER_SUPPORTS_SVE 1
+#define QT_COMPILER_SUPPORTS_VAES 1
+#define QT_COMPILER_SUPPORTS_RDRND 1
+#define QT_COMPILER_SUPPORTS_RDSEED 1
+#define QT_COMPILER_SUPPORTS_SHA 1
 #define QT_LINKED_OPENSSL
 #define QT_GUI_TEST 1
 
