@@ -1,7 +1,7 @@
 #ifndef QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
 #define QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
 
-#define QT_FEATURE_accessibility_atspi_bridge 1
+#define QT_FEATURE_accessibility_atspi_bridge -1
 
 #define QT_FEATURE_directfb -1
 
@@ -61,13 +61,13 @@
 
 #define QT_FEATURE_egl_x11 1
 
-#define QT_FEATURE_eglfs -1
+#define QT_FEATURE_eglfs 1
 
 #define QT_FEATURE_eglfs_brcm -1
 
-#define QT_FEATURE_eglfs_egldevice -1
+#define QT_FEATURE_eglfs_egldevice 1
 
-#define QT_FEATURE_eglfs_gbm -1
+#define QT_FEATURE_eglfs_gbm 1
 
 #define QT_FEATURE_eglfs_vsp2 -1
 
@@ -81,7 +81,7 @@
 
 #define QT_FEATURE_eglfs_openwfd -1
 
-#define QT_FEATURE_eglfs_x11 -1
+#define QT_FEATURE_eglfs_x11 1
 
 #define QT_FEATURE_gif 1
 
@@ -113,7 +113,7 @@
 
 #define QT_FEATURE_xcb_sm 1
 
-#define QT_FEATURE_system_xcb_xinput 1
+#define QT_FEATURE_system_xcb_xinput -1
 
 #define QT_FEATURE_xkbcommon 1
 
@@ -131,35 +131,35 @@
 
 #define QT_FEATURE_graphicsframecapture -1
 
-#define QT_FEATURE_wayland_client 1
+#define QT_FEATURE_wayland_client -1
 
-#define QT_FEATURE_wayland_server 1
+#define QT_FEATURE_wayland_server -1
 
-#define QT_FEATURE_wayland_egl 1
+#define QT_FEATURE_wayland_egl -1
 
 #define QT_FEATURE_wayland_brcm -1
 
-#define QT_FEATURE_wayland_drm_egl_server_buffer 1
+#define QT_FEATURE_wayland_drm_egl_server_buffer -1
 
 #define QT_FEATURE_wayland_libhybris_egl_server_buffer -1
 
-#define QT_FEATURE_wayland_dmabuf_server_buffer 1
+#define QT_FEATURE_wayland_dmabuf_server_buffer -1
 
-#define QT_FEATURE_wayland_shm_emulation_server_buffer 1
+#define QT_FEATURE_wayland_shm_emulation_server_buffer -1
 
-#define QT_FEATURE_wayland_vulkan_server_buffer 1
+#define QT_FEATURE_wayland_vulkan_server_buffer -1
 
 #define QT_FEATURE_wayland_datadevice 1
 
 #define QT_FEATURE_wayland_client_primary_selection 1
 
-#define QT_FEATURE_wayland_client_fullscreen_shell_v1 1
+#define QT_FEATURE_wayland_client_fullscreen_shell_v1 -1
 
-#define QT_FEATURE_wayland_client_wl_shell 1
+#define QT_FEATURE_wayland_client_wl_shell -1
 
-#define QT_FEATURE_wayland_client_xdg_shell 1
+#define QT_FEATURE_wayland_client_xdg_shell -1
 
-#define QT_FEATURE_egl_extension_platform_wayland 1
+#define QT_FEATURE_egl_extension_platform_wayland -1
 
 #define QT_FEATURE_run_opengl_tests 1
 
