@@ -21,15 +21,15 @@
 
 #define QT_FEATURE_dynamicgl -1
 
-#define QT_FEATURE_opengl -1
+#define QT_FEATURE_opengl 1
 
-#define QT_FEATURE_vulkan -1
+#define QT_FEATURE_vulkan 1
 
 #define QT_FEATURE_metal -1
 
 #define QT_FEATURE_openvg -1
 
-#define QT_FEATURE_egl -1
+#define QT_FEATURE_egl 1
 
 #define QT_FEATURE_ico 1
 
@@ -37,13 +37,13 @@
 
 #define QT_FEATURE_xcb 1
 
-#define QT_FEATURE_xcb_glx_plugin -1
+#define QT_FEATURE_xcb_glx_plugin 1
 
 #define QT_FEATURE_texthtmlparser 1
 
 #define QT_FEATURE_textmarkdownreader 1
 
-#define QT_FEATURE_system_textmarkdownreader 1
+#define QT_FEATURE_system_textmarkdownreader -1
 
 #define QT_FEATURE_textmarkdownwriter 1
 
@@ -103,7 +103,7 @@
 
 #define QT_FEATURE_systemtrayicon 1
 
-#define QT_FEATURE_accessibility 1
+#define QT_FEATURE_accessibility -1
 
 #define QT_FEATURE_whatsthis 1
 
@@ -118,7 +118,6 @@
 #define QT_FEATURE_waylandscanner -1
 
 #define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
-#define QT_NO_OPENGL 1
-#define QT_NO_EGL 1
+#define QT_NO_ACCESSIBILITY 1
 
 #endif // QT_FEATURES_Gui_src_gui_qtgui_config_h_H
