@@ -1,7 +1,7 @@
 #ifndef QT_FEATURES_Network_src_network_qtnetwork_config_p_h_H
 #define QT_FEATURES_Network_src_network_qtnetwork_config_p_h_H
 
-#define QT_FEATURE_libresolv 1
+#define QT_FEATURE_libresolv -1
 
 #define QT_FEATURE_libproxy -1
 
