@@ -29,7 +29,7 @@
 
 #define QT_FEATURE_networkdiskcache 1
 
-#define QT_FEATURE_brotli -1
+#define QT_FEATURE_brotli 1
 
 #define QT_FEATURE_localserver 1
 
@@ -44,7 +44,6 @@
 #define QT_NO_GETIFADDRS 1
 #define QT_NO_IPV6IFNAME 1
 #define QT_NO_SCTP 1
-#define QT_NO_BROTLI 1
 #define QT_NO_GSSAPI 1
 #define QT_NO_SSPI 1
 
